You are viewing a plain text version of this content. The canonical link for it is here.
Posted to issues@ozone.apache.org by "Chi-Hsuan Huang (Jira)" <ji...@apache.org> on 2026/06/02 14:02:00 UTC

[jira] [Assigned] (HDDS-10308) Speed up TestOmSnapshot

     [ https://issues.apache.org/jira/browse/HDDS-10308?page=com.atlassian.jira.plugin.system.issuetabpanels:all-tabpanel ]

Chi-Hsuan Huang reassigned HDDS-10308:
--------------------------------------

    Assignee: Chi-Hsuan Huang  (was: Wei-Chiu Chuang)

> Speed up TestOmSnapshot
> -----------------------
>
>                 Key: HDDS-10308
>                 URL: https://issues.apache.org/jira/browse/HDDS-10308
>             Project: Apache Ozone
>          Issue Type: Sub-task
>          Components: test
>            Reporter: Attila Doroszlai
>            Assignee: Chi-Hsuan Huang
>            Priority: Critical
>
> {{TestOmSnapshot}} subclasses take 24 minutes total:
> {noformat}
> Tests run: 46, Failures: 0, Errors: 0, Skipped: 7, Time elapsed: 170.3 s -- in org.apache.hadoop.ozone.om.snapshot.TestOmSnapshotObjectStoreWithLinkedBuckets
> Tests run: 46, Failures: 0, Errors: 0, Skipped: 7, Time elapsed: 170.2 s -- in org.apache.hadoop.ozone.om.snapshot.TestOmSnapshotWithBucketLinkingLegacy
> Tests run: 46, Failures: 0, Errors: 0, Skipped: 0, Time elapsed: 190.5 s -- in org.apache.hadoop.ozone.om.snapshot.TestOmSnapshotFsoWithNativeLibWithLinkedBuckets
> Tests run: 46, Failures: 0, Errors: 0, Skipped: 7, Time elapsed: 170.1 s -- in org.apache.hadoop.ozone.om.snapshot.TestOmSnapshotWithoutBucketLinkingLegacy
> Tests run: 46, Failures: 0, Errors: 0, Skipped: 0, Time elapsed: 193.8 s -- in org.apache.hadoop.ozone.om.snapshot.TestOmSnapshotFsoWithoutNativeLib
> Tests run: 46, Failures: 0, Errors: 0, Skipped: 0, Time elapsed: 192.0 s -- in org.apache.hadoop.ozone.om.snapshot.TestOmSnapshotFsoWithoutNativeLibWithLinkedBuckets
> Tests run: 46, Failures: 0, Errors: 0, Skipped: 0, Time elapsed: 194.0 s -- in org.apache.hadoop.ozone.om.snapshot.TestOmSnapshotFsoWithNativeLib
> Tests run: 46, Failures: 0, Errors: 0, Skipped: 7, Time elapsed: 169.4 s -- in org.apache.hadoop.ozone.om.snapshot.TestOmSnapshotObjectStore
> {noformat}
> Also, both {{TestOmSnapshotObjectStore}} and {{TestOmSnapshotObjectStoreWithLinkedBuckets}} run tests with {{createLinkedBucket=true}}.  The former should pass {{false}} instead.



--
This message was sent by Atlassian Jira
(v8.20.10#820010)

---------------------------------------------------------------------
To unsubscribe, e-mail: issues-unsubscribe@ozone.apache.org
For additional commands, e-mail: issues-help@ozone.apache.org